@@ -75,10 +75,10 @@ sub error {
 
 sub redirect {
     my ($destination, $status) = @_;
-    if($destination =~ m!^/!) {
+    if($destination =~ m!^(\w://)?/!) {
         # no absolute uri here, build one, RFC 2616 forces us to do so
         my $request = Dancer::SharedData->request;
-        $destination = $request->uri_for($destination);
+        $destination = $request->uri_for( $destination, {}, 1 );
     }
     Dancer::Response::status($status || 302);
     Dancer::Response::headers('Location' => $destination);
